@@ -1,4 +1,4 @@
-/* -*- mode: C -*- Time-stamp: "2010-12-21 22:03:36 jemarch"
+/* -*- mode: C -*- Time-stamp: "2011-01-31 22:13:01 jemarch"
  *
  *       File:         csv2rec.c
  *       Date:         Fri Aug 20 16:35:25 2010
@@ -113,10 +113,10 @@ Convert csv data into rec data.\n"), stdout);
   /* TRANSLATORS: --help output, csv2rec options.
      no-wrap */
   fputs (_("\
-  -t, --type                          Type name for the converted records.  If this\n\
-                                         parameter is ommited then no type is used.\n\
-  -s, --strict                        Be strict parsing the csv file.\n\
-  -e, --omit-empty                    Omit empty fields.\n"), stdout);
+  -t, --type=TYPE                     type name for the converted records; if this\n\
+                                        parameter is ommited then no type is used.\n\
+  -s, --strict                        be strict parsing the csv file.\n\
+  -e, --omit-empty                    omit empty fields.\n"), stdout);
 
   recutl_print_help_common ();
 
